@@ -17,8 +17,8 @@ class ConsulService(object):
             # 健康检查ip端口，检查时间：5,超时时间：30，注销时间：30s
             check=consul.Check().http("http://{}:{}{}".format(host,port,health_entry), "5s", "30s", "30s",None))
 
-    def check(self,host,port, interval, timeout=None, deregister=None,header=None):
-        return consul.Check.http("http://{}:{}".format(host,port),interval,timeout,deregister,header)
+    def check(self,host,port, interval, timeout=None, deregister=None,header=None,health_entry='/health',):
+        return consul.Check.http("http://{}:{}{}".format(host,port,health_entry),interval,timeout,deregister,header)
 
     def getService(self, name):
         services = self._consul.agent.services()
